#!/bin/bash
echo "Upgrading packages**"
sudo aptitude update
sudo aptitude upgrade --assume-yes
echo "**Installing packages: vim, tmux, python3, cmake, stow, fonts-powerline, snapd, etc.**"
sudo aptitude install --assume-yes git curl zsh vim tmux python3 python3-pip build-essential python3-dev python3-setuptools python3-wheel cmake stow fonts-powerline snapd lastpass-cli
echo "**Installing powerline and tmuxp**"
pip3 install powerline-status
pip3 install --user tmuxp
echo "**Installing plug.vim**"
curl -fLo ~/.vim/autoload/plug.vim --create-dirs https://raw.githubusercontent.com/junegunn/vim-plug/master/plug.vim
echo "**Installing diff-so-fancy**"
curl -fsSL -o ~/.local/bin/diff-so-fancy https://raw.githubusercontent.com/so-fancy/diff-so-fancy/master/third_party/build_fatpack/diff-so-fancy
sudo chmod 755 ~/.local/bin/diff-so-fancy
echo "**Installing Rust**"
curl https://sh.rustup.rs -sSf | sh -s -- -v -y
echo "source $HOME/.cargo/env" >> ./zsh/.zshrc
echo "**Backing up config files**"
[[ -f ~/.zshrc ]] && mv -v ~/.zshrc ~/.zshrc.bak
[[ -f ~/.vimrc ]] && mv -v ~/.vimrc ~/.vimrc.bak
[[ -f ~/.tmux.conf ]] && mv -v ~/.tmux.conf ~/.tmux.conf.bak
[[ -f ~/.git-completion ]] && mv -v ~/.git-completion ~/.git-completion.bak
[[ -f ~/.gitconfig ]] && mv -v ~/.gitconfig ~/.gitconfig.bak
[[ -f ~/.oysttyerrc ]] && mv -v ~/.oysttyerrc ~/.oysttyerrc.bak
[[ -f ~/.oysttyerkey ]] && mv -v ~/.oysttyerkey ~/.oysttyerkey.bak
[[ -f ~/.egrc ]] && mv -v ~/.egrc ~/.egrc.bak
[[ -f /usr/local/bin/consolidate-path ]] && mv -v /usr/local/bin/consolidate-path /usr/local/bin/consolidate-path.bak
echo "**Installing new config files**"
stow -t ~ zsh
stow -t ~ vim
stow -t ~ tmux
stow -t ~ git
stow -t ~ newsboat
stow -t ~ eg
stow -t ~ oysttyer
stow -t /usr/local/bin bin
echo "**Installing Heroku CLI**"
sudo snap install --classic heroku
echo "**Installing glances**"
pip3 install glances
echo "**Installing ddgr**"
pip3 install ddgr
echo "**Installing NVM**"
curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.34.0/install.sh | bash
echo "**Installing Yarn**"
curl -sS https://dl.yarnpkg.com/debian/pubkey.gpg | sudo apt-key add -
echo "deb https://dl.yarnpkg.com/debian/ stable main" | sudo tee /etc/apt/sources.list.d/yarn.list
sudo apt-get update && sudo apt-get install --no-install-recommends yarn
echo "**Installing Oh My Zsh**"
git clone https://github.com/robbyrussell/oh-my-zsh.git ~/.oh-my-zsh
echo "**Installing zsh-nvm**"
git clone https://github.com/lukechilds/zsh-nvm ~/.oh-my-zsh/custom/plugins/zsh-nvm
echo "**Switching to zsh**"
chsh -s /bin/zsh
echo "[TODO] **Download and install bat cb eg exa fd newsboat consolidate-path**"
echo "**Please restart the system and run ~/dotfiles/post-install.sh**"
/bin/zsh

